# qrmfold (Quantum Reed-Muller Fold)

A Python package to generate the full logical Clifford group
from transversal and fold-transversal gates in the quantum Reed-Muller code.

## Installation Instructions
Run `pip install qrmfold`.

## Tutorial
See [`getting_started.ipynb`](getting_started.ipynb).
For more detail on individual functions/methods,
inspect their docstrings.